
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

typedef CarillonMapBoxCreatedCallback = void Function(
    CarillonMapBoxController controller);

class CarillonMapBox extends StatefulWidget {
  const CarillonMapBox({
    Key? key,
    required this.onCarillonMapBoxCreated,
  }) : super(key: key);

  final CarillonMapBoxCreatedCallback onCarillonMapBoxCreated;

  @override
  State<StatefulWidget> createState() => _CarillonMapBoxState();
}

class _CarillonMapBoxState extends State<CarillonMapBox> {
  /*static const MethodChannel _channel = MethodChannel('carillon_map_box');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }*/

  @override
  Widget build(BuildContext context) {
    final Map<String, dynamic> creationParams = <String, dynamic>{};
    if (defaultTargetPlatform == TargetPlatform.android) {
      return PlatformViewLink(
        viewType: 'plugins/carillon_map_box',
        surfaceFactory:
            (BuildContext context, PlatformViewController controller) {
          return AndroidViewSurface(
            controller: controller as AndroidViewController,
            gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
            hitTestBehavior: PlatformViewHitTestBehavior.opaque,
          );
        },
        onCreatePlatformView: (PlatformViewCreationParams params) {
          return PlatformViewsService.initSurfaceAndroidView(
            id: params.id,
            viewType: 'plugins/carillon_map_box',
            layoutDirection: TextDirection.ltr,
            creationParams: creationParams,
            creationParamsCodec: StandardMessageCodec(),
            onFocus: () {
              params.onFocusChanged(true);
            },
          )
            ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
            ..create();
        },
      );
    }
    return const Text('iOS platform version is not implemented yet.');
  }

  void _onPlatformViewCreated(int id) {
    if (widget.onCarillonMapBoxCreated == null) {
      return;
    }
    widget.onCarillonMapBoxCreated(CarillonMapBoxController._(id));
  }
}

class CarillonMapBoxController {
  CarillonMapBoxController._(int id)
      : _channel = MethodChannel('plugins/carillon_map_box_$id');

  final MethodChannel _channel;

  MethodChannel getChannel() {
    return _channel;
  }
}